@@ -123,7 +123,7 @@ class CrowdTangle:
         response = self.make_request_leader(payload)
         return response.json()
 
-    def get_post(self, include_history=False, post_id=''):
+    def get_post(self, include_history='none', post_id=''):
         """
         Returns the post with the id passed
         Args:
